# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: advance_common/messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61\x64vance_common/messages.proto\"A\n\x08Position\x12\x10\n\x08latitude\x18\x01 \x01(\x02\x12\x11\n\tlongitude\x18\x02 \x01(\x02\x12\x10\n\x08\x61ltitude\x18\x03 \x01(\x02\"1\n\nPosition2D\x12\x10\n\x08latitude\x18\x01 \x01(\x02\x12\x11\n\tlongitude\x18\x02 \x01(\x02\"Q\n\x0bMarkerGroup\x12\x1d\n\x08position\x18\x01 \x01(\x0b\x32\x0b.Position2D\x12\x0b\n\x03rgb\x18\x03 \x01(\r\x12\x16\n\x0enum_of_markers\x18\x04 \x01(\r\"4\n\x14MarkerGroupDetection\x12\x1c\n\x06groups\x18\x01 \x03(\x0b\x32\x0c.MarkerGroup\"c\n\x0fMarkerDetection\x12\x1b\n\x08position\x18\x01 \x01(\x0b\x32\t.Position\x12\x12\n\nconfidence\x18\x02 \x01(\x02\x12\t\n\x01r\x18\x03 \x01(\r\x12\t\n\x01g\x18\x04 \x01(\r\x12\t\n\x01\x62\x18\x05 \x01(\r\"\xb8\x01\n\x0fJetsonHeartBeat\x12\x18\n\x10markers_detected\x18\x01 \x01(\r\x12\x16\n\x0eimages_per_sec\x18\x02 \x01(\x02\x12\x19\n\x11telemetry_per_sec\x18\x03 \x01(\x02\x12\x1a\n\x12ram_memory_used_mb\x18\x04 \x01(\x02\x12\x10\n\x08\x63pu_load\x18\x05 \x01(\x02\x12\x13\n\x0btemperature\x18\x06 \x01(\x02\x12\x15\n\rinput_voltage\x18\x07 \x01(\x02\"\x97\x01\n\nSwitchMode\x12$\n\x04mode\x18\x01 \x01(\x0e\x32\x16.SwitchMode.ModeJetson\x12\t\n\x01r\x18\x02 \x01(\r\x12\t\n\x01g\x18\x03 \x01(\r\x12\t\n\x01\x62\x18\x04 \x01(\r\x12\x0c\n\x04wind\x18\x05 \x01(\x08\"4\n\nModeJetson\x12\x0b\n\x07\x44ISABLE\x10\x00\x12\n\n\x06SEARCH\x10\x01\x12\r\n\tDETECTION\x10\x02\"\xce\x01\n\x0bModeMessage\x12\x1f\n\x04mode\x18\x01 \x01(\x0e\x32\x11.ModeMessage.Mode\"\x9d\x01\n\x04Mode\x12\x0b\n\x07INVALID\x10\x00\x12\x14\n\x10\x43ONNECTION_CHECK\x10\x01\x12\x1a\n\x16\x44\x45\x46\x41ULT_MISSION_UPLOAD\x10\x02\x12\x15\n\x11WAIT_TARGET_COLOR\x10\x03\x12\x08\n\x04IDLE\x10\x04\x12\n\n\x06SEARCH\x10\x05\x12\x12\n\x0eUPLOAD_MISSION\x10\x06\x12\x0b\n\x07RELEASE\x10\x07\x12\x08\n\x04\x44ONE\x10\x08\">\n\x0ePositionUpdate\x12\x1b\n\x08position\x18\x01 \x01(\x0b\x32\t.Position\x12\x0f\n\x07heading\x18\x02 \x01(\x02\"\xbc\x01\n\x14JetsonAdvanceRequest\x12\x34\n\x07request\x18\x01 \x01(\x0e\x32#.JetsonAdvanceRequest.DockerRequest\"n\n\rDockerRequest\x12\x0e\n\nDO_NOTHING\x10\x00\x12\x12\n\x0e\x44OCKER_RESTART\x10\x01\x12\x13\n\x0fJETSON_POWEROFF\x10\x02\x12\x10\n\x0cRFKILL_BLOCK\x10\x03\x12\x12\n\x0eRFKILL_UNBLOCK\x10\x04\"\'\n\x06GpsFix\x12\x10\n\x08\x66ix_type\x18\x01 \x01(\x05\x12\x0b\n\x03sat\x18\x02 \x01(\x05\"\x14\n\x12ReleaseToDetection\"\xbb\x05\n\x0cSaeTelemetry\x12\x1b\n\x08\x61ircraft\x18\x01 \x01(\x0e\x32\t.Aircraft\x12#\n\x0bmode_status\x18\x02 \x01(\x0b\x32\x0c.ModeMessageH\x00\x12+\n\x13\x63hange_mode_request\x18\x03 \x01(\x0b\x32\x0c.ModeMessageH\x00\x12,\n\x10marker_detection\x18\x04 \x01(\x0b\x32\x10.MarkerDetectionH\x00\x12*\n\x0fposition_update\x18\x05 \x01(\x0b\x32\x0f.PositionUpdateH\x00\x12!\n\x0cpada_release\x18\x06 \x01(\x0b\x32\t.PositionH\x00\x12#\n\x0e\x64\x65\x62ug_waypoint\x18\x07 \x01(\x0b\x32\t.PositionH\x00\x12\x1d\n\x08waypoint\x18\x08 \x01(\x0b\x32\t.PositionH\x00\x12\x1f\n\nland_point\x18\t \x01(\x0b\x32\t.PositionH\x00\x12\"\n\x0bswitch_mode\x18\n \x01(\x0b\x32\x0b.SwitchModeH\x00\x12\x33\n\x14release_to_detection\x18\x0b \x01(\x0b\x32\x13.ReleaseToDetectionH\x00\x12.\n\rmarkers_group\x18\x0c \x01(\x0b\x32\x15.MarkerGroupDetectionH\x00\x12-\n\x11jetson_hearthbeat\x18\r \x01(\x0b\x32\x10.JetsonHeartBeatH\x00\x12\x33\n\x12jetson_adv_request\x18\x0e \x01(\x0b\x32\x15.JetsonAdvanceRequestH\x00\x12!\n\x07pa_mode\x18\x0f \x01(\x0e\x32\x0e.ArdupilotModeH\x00\x12#\n\tpada_mode\x18\x10 \x01(\x0e\x32\x0e.ArdupilotModeH\x00\x12\x1a\n\x07gps_fix\x18\x11 \x01(\x0b\x32\x07.GpsFixH\x00\x42\t\n\x07message*Z\n\x08\x41ircraft\x12\x0e\n\nDO_NOT_USE\x10\x00\x12\x14\n\x10PRIMARY_AIRCRAFT\x10\x01\x12(\n$POWERED_AUTONOMOUS_DELIVERY_AIRCRAFT\x10\x02*\x9c\x02\n\rArdupilotMode\x12\n\n\x06Manual\x10\x00\x12\n\n\x06\x43IRCLE\x10\x01\x12\r\n\tSTABILIZE\x10\x02\x12\x0c\n\x08TRAINING\x10\x03\x12\x08\n\x04\x41\x43RO\x10\x04\x12\x08\n\x04\x46\x42WA\x10\x05\x12\x08\n\x04\x46\x42WB\x10\x06\x12\n\n\x06\x43RUISE\x10\x07\x12\x0c\n\x08\x41UTOTUNE\x10\x08\x12\x08\n\x04\x41uto\x10\n\x12\x07\n\x03RTL\x10\x0b\x12\n\n\x06Loiter\x10\x0c\x12\x0b\n\x07TAKEOFF\x10\r\x12\x0e\n\nAVOID_ADSB\x10\x0e\x12\n\n\x06Guided\x10\x0f\x12\x0e\n\nQSTABILIZE\x10\x11\x12\n\n\x06QHOVER\x10\x12\x12\x0b\n\x07QLOITER\x10\x13\x12\t\n\x05QLAND\x10\x14\x12\x08\n\x04QRTL\x10\x15\x12\r\n\tQAUTOTUNE\x10\x16\x12\t\n\x05QACRO\x10\x17\x62\x06proto3')

_AIRCRAFT = DESCRIPTOR.enum_types_by_name['Aircraft']
Aircraft = enum_type_wrapper.EnumTypeWrapper(_AIRCRAFT)
_ARDUPILOTMODE = DESCRIPTOR.enum_types_by_name['ArdupilotMode']
ArdupilotMode = enum_type_wrapper.EnumTypeWrapper(_ARDUPILOTMODE)
DO_NOT_USE = 0
PRIMARY_AIRCRAFT = 1
POWERED_AUTONOMOUS_DELIVERY_AIRCRAFT = 2
Manual = 0
CIRCLE = 1
STABILIZE = 2
TRAINING = 3
ACRO = 4
FBWA = 5
FBWB = 6
CRUISE = 7
AUTOTUNE = 8
Auto = 10
RTL = 11
Loiter = 12
TAKEOFF = 13
AVOID_ADSB = 14
Guided = 15
QSTABILIZE = 17
QHOVER = 18
QLOITER = 19
QLAND = 20
QRTL = 21
QAUTOTUNE = 22
QACRO = 23


_POSITION = DESCRIPTOR.message_types_by_name['Position']
_POSITION2D = DESCRIPTOR.message_types_by_name['Position2D']
_MARKERGROUP = DESCRIPTOR.message_types_by_name['MarkerGroup']
_MARKERGROUPDETECTION = DESCRIPTOR.message_types_by_name['MarkerGroupDetection']
_MARKERDETECTION = DESCRIPTOR.message_types_by_name['MarkerDetection']
_JETSONHEARTBEAT = DESCRIPTOR.message_types_by_name['JetsonHeartBeat']
_SWITCHMODE = DESCRIPTOR.message_types_by_name['SwitchMode']
_MODEMESSAGE = DESCRIPTOR.message_types_by_name['ModeMessage']
_POSITIONUPDATE = DESCRIPTOR.message_types_by_name['PositionUpdate']
_JETSONADVANCEREQUEST = DESCRIPTOR.message_types_by_name['JetsonAdvanceRequest']
_GPSFIX = DESCRIPTOR.message_types_by_name['GpsFix']
_RELEASETODETECTION = DESCRIPTOR.message_types_by_name['ReleaseToDetection']
_SAETELEMETRY = DESCRIPTOR.message_types_by_name['SaeTelemetry']
_SWITCHMODE_MODEJETSON = _SWITCHMODE.enum_types_by_name['ModeJetson']
_MODEMESSAGE_MODE = _MODEMESSAGE.enum_types_by_name['Mode']
_JETSONADVANCEREQUEST_DOCKERREQUEST = _JETSONADVANCEREQUEST.enum_types_by_name['DockerRequest']
Position = _reflection.GeneratedProtocolMessageType('Position', (_message.Message,), {
  'DESCRIPTOR' : _POSITION,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:Position)
  })
_sym_db.RegisterMessage(Position)

Position2D = _reflection.GeneratedProtocolMessageType('Position2D', (_message.Message,), {
  'DESCRIPTOR' : _POSITION2D,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:Position2D)
  })
_sym_db.RegisterMessage(Position2D)

MarkerGroup = _reflection.GeneratedProtocolMessageType('MarkerGroup', (_message.Message,), {
  'DESCRIPTOR' : _MARKERGROUP,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:MarkerGroup)
  })
_sym_db.RegisterMessage(MarkerGroup)

MarkerGroupDetection = _reflection.GeneratedProtocolMessageType('MarkerGroupDetection', (_message.Message,), {
  'DESCRIPTOR' : _MARKERGROUPDETECTION,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:MarkerGroupDetection)
  })
_sym_db.RegisterMessage(MarkerGroupDetection)

MarkerDetection = _reflection.GeneratedProtocolMessageType('MarkerDetection', (_message.Message,), {
  'DESCRIPTOR' : _MARKERDETECTION,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:MarkerDetection)
  })
_sym_db.RegisterMessage(MarkerDetection)

JetsonHeartBeat = _reflection.GeneratedProtocolMessageType('JetsonHeartBeat', (_message.Message,), {
  'DESCRIPTOR' : _JETSONHEARTBEAT,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:JetsonHeartBeat)
  })
_sym_db.RegisterMessage(JetsonHeartBeat)

SwitchMode = _reflection.GeneratedProtocolMessageType('SwitchMode', (_message.Message,), {
  'DESCRIPTOR' : _SWITCHMODE,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:SwitchMode)
  })
_sym_db.RegisterMessage(SwitchMode)

ModeMessage = _reflection.GeneratedProtocolMessageType('ModeMessage', (_message.Message,), {
  'DESCRIPTOR' : _MODEMESSAGE,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:ModeMessage)
  })
_sym_db.RegisterMessage(ModeMessage)

PositionUpdate = _reflection.GeneratedProtocolMessageType('PositionUpdate', (_message.Message,), {
  'DESCRIPTOR' : _POSITIONUPDATE,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:PositionUpdate)
  })
_sym_db.RegisterMessage(PositionUpdate)

JetsonAdvanceRequest = _reflection.GeneratedProtocolMessageType('JetsonAdvanceRequest', (_message.Message,), {
  'DESCRIPTOR' : _JETSONADVANCEREQUEST,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:JetsonAdvanceRequest)
  })
_sym_db.RegisterMessage(JetsonAdvanceRequest)

GpsFix = _reflection.GeneratedProtocolMessageType('GpsFix', (_message.Message,), {
  'DESCRIPTOR' : _GPSFIX,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:GpsFix)
  })
_sym_db.RegisterMessage(GpsFix)

ReleaseToDetection = _reflection.GeneratedProtocolMessageType('ReleaseToDetection', (_message.Message,), {
  'DESCRIPTOR' : _RELEASETODETECTION,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:ReleaseToDetection)
  })
_sym_db.RegisterMessage(ReleaseToDetection)

SaeTelemetry = _reflection.GeneratedProtocolMessageType('SaeTelemetry', (_message.Message,), {
  'DESCRIPTOR' : _SAETELEMETRY,
  '__module__' : 'advance_common.messages_pb2'
  # @@protoc_insertion_point(class_scope:SaeTelemetry)
  })
_sym_db.RegisterMessage(SaeTelemetry)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AIRCRAFT._serialized_start=1959
  _AIRCRAFT._serialized_end=2049
  _ARDUPILOTMODE._serialized_start=2052
  _ARDUPILOTMODE._serialized_end=2336
  _POSITION._serialized_start=33
  _POSITION._serialized_end=98
  _POSITION2D._serialized_start=100
  _POSITION2D._serialized_end=149
  _MARKERGROUP._serialized_start=151
  _MARKERGROUP._serialized_end=232
  _MARKERGROUPDETECTION._serialized_start=234
  _MARKERGROUPDETECTION._serialized_end=286
  _MARKERDETECTION._serialized_start=288
  _MARKERDETECTION._serialized_end=387
  _JETSONHEARTBEAT._serialized_start=390
  _JETSONHEARTBEAT._serialized_end=574
  _SWITCHMODE._serialized_start=577
  _SWITCHMODE._serialized_end=728
  _SWITCHMODE_MODEJETSON._serialized_start=676
  _SWITCHMODE_MODEJETSON._serialized_end=728
  _MODEMESSAGE._serialized_start=731
  _MODEMESSAGE._serialized_end=937
  _MODEMESSAGE_MODE._serialized_start=780
  _MODEMESSAGE_MODE._serialized_end=937
  _POSITIONUPDATE._serialized_start=939
  _POSITIONUPDATE._serialized_end=1001
  _JETSONADVANCEREQUEST._serialized_start=1004
  _JETSONADVANCEREQUEST._serialized_end=1192
  _JETSONADVANCEREQUEST_DOCKERREQUEST._serialized_start=1082
  _JETSONADVANCEREQUEST_DOCKERREQUEST._serialized_end=1192
  _GPSFIX._serialized_start=1194
  _GPSFIX._serialized_end=1233
  _RELEASETODETECTION._serialized_start=1235
  _RELEASETODETECTION._serialized_end=1255
  _SAETELEMETRY._serialized_start=1258
  _SAETELEMETRY._serialized_end=1957
# @@protoc_insertion_point(module_scope)
